@@ -30,6 +30,7 @@ from .error_codes import (
 from .git_ops import GitError
 from .github_async import GraphQLError, RateLimitError, SecondaryRateLimitError
 from .github_client import GitHubClient
+from .github_service import AUTOMATION_TOOLS
 from .merge_manager import AsyncMergeManager
 from .models import PullRequestInfo
 from .pr_comparator import PRComparator
@@ -128,7 +129,7 @@ def _generate_continue_sha(
     pr_info: PullRequestInfo, commit_message_first_line: str
 ) -> str:
     """
-    Generate a SHA hash for continuing after dry-run evaluation.
+    Generate a SHA hash for continuing after preview evaluation.
 
     Args:
         pr_info: Source pull request information
@@ -137,7 +138,7 @@ def _generate_continue_sha(
     Returns:
         SHA256 hash string for continuation
     """
-    # Create a string combining source PR info for dry-run continuation
+    # Create a string combining source PR info for preview continuation
     combined_data = f"continue:{pr_info.repository_full_name}#{pr_info.number}:{commit_message_first_line.strip()}"
 
     # Generate SHA256 hash
@@ -189,7 +190,7 @@ def merge(
     no_confirm: bool = typer.Option(
         False,
         "--no-confirm",
-        help="Skip confirmation prompt and merge immediately without dry-run",
+        help="Skip confirmation prompt and merge immediately",
     ),
     similarity_threshold: float = typer.Option(
         0.8, "--threshold", help="Similarity threshold for matching PRs (0.0-1.0)"
@@ -222,9 +223,9 @@ def merge(
         help="Automatically dismiss unresolved GitHub Copilot review comments",
     ),
     force: str = typer.Option(
-        "none",
+        "code-owners",
         "--force",
-        help="Override level: 'none', 'code-owners', 'protection-rules', 'all' (use with caution)",
+        help="Override level: 'none', 'code-owners', 'protection-rules', 'all' (default: code-owners)",
     ),
 ):
     """
@@ -248,8 +249,8 @@ def merge(
     For user generated bulk PRs, use the --override flag with SHA hash.
 
     Force levels:
-    - none: Respect all protections (default)
-    - code-owners: Bypass code owner review requirements
+    - none: Respect all protections
+    - code-owners: Bypass code owner review requirements (default)
     - protection-rules: Bypass branch protection checks (requires permissions)
     - all: Attempt merge despite most warnings (not recommended)
     """
@@ -510,12 +511,12 @@ def merge(
                 concurrency=10,  # Process up to 10 PRs concurrently
                 fix_out_of_date=not no_fix,  # Fix is default, --no-fix disables it
                 progress_tracker=progress_tracker,
-                dry_run=not no_confirm,
+                preview_mode=not no_confirm,
                 dismiss_copilot=dismiss_copilot,
                 force_level=force,
             ) as merge_manager:
                 if not no_confirm:
-                    pass  # No merge message in dry-run mode
+                    pass  # No merge message in preview mode
                 else:
                     console.print(
                         f"\n🚀 Merging {len(all_prs_to_merge)} pull requests..."
@@ -572,7 +573,7 @@ def merge(
                             for i, result in enumerate(merge_results):
                                 if (
                                     result.status.value == "merged"
-                                ):  # These were dry-run "merged"
+                                ):  # These were preview "merged"
                                     mergeable_prs.append(all_prs_to_merge[i])
 
                             # Define async function for real merge
@@ -584,7 +585,7 @@ def merge(
                                     concurrency=10,
                                     fix_out_of_date=not no_fix,
                                     progress_tracker=progress_tracker,
-                                    dry_run=False,  # Real merge this time
+                                    preview_mode=False,  # Execute merge
                                     dismiss_copilot=dismiss_copilot,
                                     force_level=force,
                                 ) as real_merge_manager:
@@ -625,7 +626,7 @@ def merge(
                     except EOFError:
                         console.print("\n❌ Merge cancelled.")
 
-                    return  # Exit after handling dry-run continuation
+                    return  # Exit after handling preview continuation
                 else:
                     console.print("\n💡 No PRs are mergeable at this time.")
             else:
@@ -730,7 +731,7 @@ def close(
     no_confirm: bool = typer.Option(
         False,
         "--no-confirm",
-        help="Skip confirmation prompt and close immediately without dry-run",
+        help="Skip confirmation prompt and close immediately without preview",
     ),
     similarity_threshold: float = typer.Option(
         0.8, "--threshold", help="Similarity threshold for matching PRs (0.0-1.0)"
@@ -927,19 +928,19 @@ def close(
         # Determine which PRs to close
         all_prs_to_close = [source_pr] + [pr for pr, _ in all_similar_prs]
 
-        # Perform dry-run close operation
-        async def _close_parallel(prs, dry_run_mode):
+        # Perform preview close operation
+        async def _close_parallel(prs, preview_mode):
             close_manager = AsyncCloseManager(
                 token=token,
                 progress_tracker=progress_tracker,
-                dry_run=dry_run_mode,
+                preview_mode=preview_mode,
             )
             async with close_manager:
                 # Convert to list of tuples (PR, None) for consistency
                 pr_tuples = [(pr, None) for pr in prs]
                 return await close_manager.close_prs_parallel(pr_tuples)
 
-        # Perform dry-run to check which PRs can be closed
+        # Perform preview to check which PRs can be closed
         if not no_confirm:
             if progress_tracker:
                 progress_tracker.start()
@@ -997,7 +998,7 @@ def close(
                         for i, result in enumerate(close_results):
                             if (
                                 result.status.value == "closed"
-                            ):  # These were dry-run "closed"
+                            ):  # These were preview "closed"
                                 closeable_prs.append(all_prs_to_close[i])
 
                         if progress_tracker:
@@ -1093,9 +1094,10 @@ def close(
 
 
 @app.command()
-def blocked(
-    organization: str = typer.Argument(
-        ..., help="GitHub organization name to check for blocked PRs"
+def status(
+    org_input: str = typer.Argument(
+        ...,
+        help="GitHub organization name or URL (e.g., 'lfreleng-actions' or 'https://github.com/lfreleng-actions/')",
     ),
     token: str | None = typer.Option(
         None, "--token", help="GitHub token (or set GITHUB_TOKEN env var)"
@@ -1103,6 +1105,102 @@ def blocked(
     output_format: str = typer.Option(
         "table", "--format", help="Output format: table, json"
     ),
+    show_progress: bool = typer.Option(
+        True, "--progress/--no-progress", help="Show real-time progress updates"
+    ),
+):
+    """
+    Reports repository statistics for tags, releases and pull requests.
+
+    This command will:
+    1. Scan all repositories in the organization
+    2. Gather tag and release information
+    3. Count open and merged pull requests
+    4. Identify PRs affecting actions or workflows
+
+    Automation tools supported: dependabot, pre-commit.ci
+    """
+    # Parse organization name from input (handle both URL and plain name)
+    org_name = org_input.rstrip("/").split("/")[-1]
+    if not org_name:
+        console.print("❌ Invalid GitHub organization name or URL")
+        console.print(
+            "   Expected: 'organization-name' or 'https://github.com/organization-name/'"
+        )
+        raise typer.Exit(1)
+
+    # Initialize progress tracker (disable PR stats for status command)
+    progress_tracker = None
+
+    try:
+        if show_progress:
+            progress_tracker = ProgressTracker(org_name, show_pr_stats=False)
+            progress_tracker.start()
+            if not progress_tracker.rich_available:
+                console.print(f"🔍 Scanning organization: {org_name}")
+                console.print("Progress updates will be shown as simple text...")
+        else:
+            console.print(f"🔍 Scanning organization: {org_name}")
+            console.print("This may take a few minutes for large organizations...")
+
+        # Perform the scan
+        from .github_service import GitHubService
+
+        async def _run_status_check():
+            svc = GitHubService(token=token, progress_tracker=progress_tracker)
+            try:
+                return await svc.gather_organization_status(org_name)
+            finally:
+                await svc.close()
+
+        status_result = asyncio.run(_run_status_check())
+
+        # Stop progress tracker before displaying results
+        if progress_tracker:
+            progress_tracker.stop()
+            if progress_tracker.rich_available:
+                console.print()
+            else:
+                console.print()
+
+            # Show scan summary
+            summary = progress_tracker.get_summary()
+            elapsed_time = summary.get("elapsed_time")
+            console.print(f"\n✅ Scan completed in {elapsed_time}")
+            console.print()
+
+        # Display results
+        _display_status_results(status_result, output_format)
+
+    except KeyboardInterrupt:
+        if progress_tracker:
+            progress_tracker.stop()
+        console.print("\n⚠️  Scan interrupted by user")
+        raise typer.Exit(130) from None
+    except Exception as e:
+        if progress_tracker:
+            progress_tracker.stop()
+        console.print(f"❌ Error during scan: {e}")
+        raise typer.Exit(1) from e
+
+
+@app.command()
+def blocked(
+    org_input: str = typer.Argument(
+        ...,
+        help="GitHub organization name or URL (e.g., 'lfreleng-actions' or 'https://github.com/lfreleng-actions/')",
+    ),
+    token: str | None = typer.Option(
+        None, "--token", help="GitHub token (or set GITHUB_TOKEN env var)"
+    ),
+    output_format: str = typer.Option(
+        "table", "--format", help="Output format: table, json"
+    ),
+    include_drafts: bool = typer.Option(
+        False,
+        "--include-drafts",
+        help="Include draft pull requests in the blocked PRs report",
+    ),
     fix: bool = typer.Option(
         False,
         "--fix",
@@ -1159,6 +1257,15 @@ def blocked(
 
     Standard code review requirements are not considered blocking.
     """
+    # Parse organization name from input (handle both URL and plain name)
+    organization = org_input.rstrip("/").split("/")[-1]
+    if not organization:
+        console.print("❌ Invalid GitHub organization name or URL")
+        console.print(
+            "   Expected: 'organization-name' or 'https://github.com/organization-name/'"
+        )
+        raise typer.Exit(1)
+
     # Initialize progress tracker
     progress_tracker = None
 
@@ -1180,7 +1287,9 @@ def blocked(
         async def _run_blocked_check():
             svc = GitHubService(token=token, progress_tracker=progress_tracker)
             try:
-                return await svc.scan_organization(organization)
+                return await svc.scan_organization(
+                    organization, include_drafts=include_drafts
+                )
             finally:
                 await svc.close()
 
@@ -1320,7 +1429,7 @@ def _display_blocked_results(scan_result, output_format: str):
     if output_format == "json":
         import json
 
-        console.print(json.dumps(scan_result.dict(), indent=2, default=str))
+        console.print(json.dumps(scan_result.model_dump(), indent=2, default=str))
         return
 
     # Table format
@@ -1391,5 +1500,100 @@ def _display_blocked_results(scan_result, output_format: str):
         console.print(error_table)
 
 
+def _display_status_results(status_result, output_format: str):
+    """Display the organization status results."""
+
+    if output_format == "json":
+        import json
+
+        console.print(json.dumps(status_result.model_dump(), indent=2, default=str))
+        return
+
+    # Table format
+    if not status_result.repository_statuses:
+        console.print("❌ No repositories found in organization!")
+        return
+
+    # Create status table
+    status_table = Table(title=f"Organization: {status_result.organization}")
+    status_table.add_column("Repository", style="cyan")
+    status_table.add_column("Tag", style="white")
+    status_table.add_column("Date", style="white")
+    status_table.add_column("PRs Open", style="white")
+    status_table.add_column("PRs Merged", style="white")
+    status_table.add_column("Action", style="white")
+    status_table.add_column("Workflows", style="white")
+
+    for repo in status_result.repository_statuses:
+        # Format tag with icon
+        tag_display = "—"
+        if repo.latest_tag:
+            tag_display = f"{repo.status_icon} {repo.latest_tag}"
+
+        # Format date
+        date_display = repo.tag_date or repo.release_date or "—"
+
+        # Format PR counts
+        open_prs = f"{repo.open_prs_human} / {repo.open_prs_automation}"
+        merged_prs = f"{repo.merged_prs_human} / {repo.merged_prs_automation}"
+        action_prs = f"{repo.action_prs_human} / {repo.action_prs_automation}"
+        workflow_prs = f"{repo.workflow_prs_human} / {repo.workflow_prs_automation}"
+
+        status_table.add_row(
+            repo.repository_name,
+            tag_display,
+            date_display,
+            open_prs,
+            merged_prs,
+            action_prs,
+            workflow_prs,
+        )
+
+    console.print(status_table)
+    console.print()
+    console.print("PR counts are for human/automation")
+    console.print("\nAutomation tools supported:")
+    for tool in AUTOMATION_TOOLS:
+        # Format tool names nicely
+        if tool == "[bot]":
+            console.print("  • Any bot account")
+        elif tool == "pre-commit":
+            console.print("  • pre-commit.ci")
+        elif tool == "github-actions":
+            console.print("  • GitHub Actions")
+        else:
+            console.print(f"  • {tool.capitalize()}")
+    console.print()
+
+    # Create summary table
+    summary_table = Table()
+    summary_table.add_column("Summary", style="cyan")
+    summary_table.add_column("Value", style="white")
+
+    summary_table.add_row("Total Repositories", str(status_result.total_repositories))
+
+    # Only show Scanned Repositories if it differs from Total
+    if status_result.scanned_repositories != status_result.total_repositories:
+        summary_table.add_row(
+            "Scanned Repositories", str(status_result.scanned_repositories)
+        )
+
+    if status_result.errors:
+        summary_table.add_row("Errors", str(len(status_result.errors)), style="red")
+
+    console.print(summary_table)
+
+    # Show errors if any
+    if status_result.errors:
+        console.print()
+        error_table = Table(title="Errors Encountered During Scan")
+        error_table.add_column("Error", style="red")
+
+        for error in status_result.errors:
+            error_table.add_row(error)
+
+        console.print(error_table)
+
+
 if __name__ == "__main__":
     app()
